# (c) Copyright 2014,2015 Hewlett-Packard Development Company, L.P.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#    http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

"""
URL patterns for the OpenStack Dashboard.
"""

from django.urls import re_path

from disaster_recovery.api.rest import rest_api

urlpatterns = [
    re_path(r'^api/clients/$', rest_api.Clients.as_view(),
            name="api_clients"),
    re_path(r'^api/actions/$', rest_api.ActionList.as_view(),
            name="api_actions"),
    re_path(r'^api/actions/job/(?P<job_id>[^/]+)?$',
            rest_api.Actions.as_view(), name="api_actions_in_job"),
]
